@@ -10,10 +10,10 @@ class AppEnvironmentClusterEnvChoices(ChoiceSet):
     CHOICE_DEV = 'DEV'
 
     CHOICES = [
-        (CHOICE_PRD, 'PRD', 'gray'),
-        (CHOICE_INT, 'INT', 'green'),
+        (CHOICE_PRD, 'PRD', 'red'),
+        (CHOICE_INT, 'INT', 'yellow'),
         (CHOICE_TST, 'TST', 'cyan'),
-        (CHOICE_DEV, 'DEV', 'blue'),
+        (CHOICE_DEV, 'DEV', 'green'),
     ]
 
 
