@@ -84,18 +84,145 @@ class OCPProject(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/OCPProject/'
 
-    def export_yaml_dict(self):
+    def ocp_project_get_yaml(self):
         return {
+            'name': 'ti8m-squash-tm-added',
+            'description': 'An application to manage test cases from ti&m.',
+            'displayName': 'ti8m-squash-tm',
+            'customer': 'ti&m',
+            'owner': 'Tim R',
+            'contact': 'tim.rhomberg@ti8m.ch',
+            'workloads': 'Postgres DB, Squash-TM',
+            'request': 'SDTIM-12345',
+            'environments': {
+                'TST': [
+                    {
+                        'appEnv': 'tst',
+                        'monitoring': 'false',
+                        'postgresMonitoring': 'false',
+                        'kustomize': 'true',
+                        'deployment': {
+                            'repo': 'https://gitlab.ti8m.ch/edb/squash-tm-deployment.git',
+                            'branch': 'main',
+                            'path': 'overlays/tst'
+                        },
+                        'resourceQuota': {
+                            'requests': {
+                                'cpu': 2,
+                                'memory': '200Mi'
+                            },
+                            'limits': {
+                                'cpu': 1,
+                                'memory': 1
+                            }
+                        }
+                    }
+                ],
+                'INT': [
+                    {
+                        'appEnv': 'tst',
+                        'monitoring': 'true',
+                        'postgresMonitoring': 'true',
+                        'kustomize': 'true',
+                        'deployment': {
+                            'repo': 'https://gitlab.ti8m.ch/edb/squash-tm-deployment.git',
+                            'branch': 'main',
+                            'path': 'overlays/tst'
+                        },
+                        'resourceQuota': {
+                            'requests': {
+                                'cpu': 1,
+                                'memory': 1
+                            },
+                            'limits': {
+                                'cpu': 1,
+                                'memory': 1
+                            }
+                        }
+                    }
+                ],
+                'PRD': [
+                    {
+                        'appEnv': 'tst',
+                        'monitoring': 'true',
+                        'postgresMonitoring': 'true',
+                        'kustomize': 'true',
+                        'deployment': {
+                            'repo': 'https://gitlab.ti8m.ch/edb/squash-tm-deployment.git',
+                            'branch': 'main',
+                            'path': 'overlays/tst'
+                        },
+                        'resourceQuota': {
+                            'requests': {
+                                'cpu': 1,
+                                'memory': 1
+                            },
+                            'limits': {
+                                'cpu': 1,
+                                'memory': 1
+                            }
+                        }
+                    }
+                ]
+            }
+        }
+
+    def export_yaml_dict(self):
+        yaml_object = {
             'name': self.name,
             'description': self.description,
             'displayName': self.display_name,
-            'customer': self.customer,
-            'owner': self.owner,
-            'contact': self.contact,
+            'customer': self.customer.name,
+            'owner': self.owner.name,
+            'contact': self.contact.name,
             'workloads': self.workload,
             'request': self.request,
-            'url': self.docu_url
+            'url': self.docu_url,
+            'environments': {
+
+            }
         }
+        if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_DEV)) > 0:
+            yaml_object['environments']['DEV'] = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_DEV)
+        if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_TST)) > 0:
+            app_env_list = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_TST)
+            yaml_object['environments']['TST'] = app_env_list
+        if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_INT)) > 0:
+            yaml_object['environments']['INT'] = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_INT)
+        if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_PRD)) > 0:
+            yaml_object['environments']['PRD'] = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_PRD)
+
+        get_queue("default").enqueue("ocp_project_plugin.worker.sync_project", yaml_object)
+        print(yaml_object)
+        return yaml_object
+
+    def get_app_env(self, app_env_choice):
+        app_env_queryset = AppEnvironment.objects.filter(cluster_env=app_env_choice, ocp_project=self)
+
+        app_env_list = []
+        for app_env in app_env_queryset:
+            #@TODO deployment kind
+            app_env_list.append({
+                'appEnv': app_env.app_env,
+                'monitoring': app_env.monitoring,
+                'postgresMonitoring': app_env.postgres_monitoring,
+                'deployment': {
+                    'repo': app_env.repo,
+                    'branch': app_env.branch,
+                    'path': app_env.path
+                },
+                'resourceQuota': {
+                    'requests': {
+                        'cpu': app_env.requests_cpu,
+                        'memory': app_env.requests_memory
+                    },
+                    'limits': {
+                        'cpu': app_env.limits_cpu,
+                        'memory': app_env.limits_memory
+                    }
+                }
+            })
+        return app_env_list
 
     def count_app_environments(self):
         return AppEnvironment.objects.filter(OCPProject=self).count()
@@ -220,7 +347,8 @@ class AppEnvironment(NetBoxModel):
         return f'https://confluence.ti8m.ch/docs/models/AppEnvironment/'
 
     def save(self, *args, **kwargs):
-        get_queue("default").enqueue("ocp_project_plugin.worker.pull_repository")
+        #get_queue("default").enqueue("ocp_project_plugin.worker.pull_repository")
+        print(self.ocp_project.export_yaml_dict())
         super(AppEnvironment, self).save(*args, **kwargs)
 
     def get_cluster_color(self):
@@ -231,9 +359,9 @@ class AppEnvironment(NetBoxModel):
             return 0
         else:
             if str(self.limits_memory).endswith('Mi'):
-                return int(MEMORY_COST) * float(str(self.limits_memory)[:-2]) / 1000
+                return float(str(self.limits_memory)[:-2]) / 1000
             else:
-                return int(MEMORY_COST) * float(str(self.limits_memory)[:-2])
+                return float(str(self.limits_memory)[:-2])
 
     def calculate_cpu_cost(self):
         return Decimal(CPU_COST) * DecimalField().to_python(self.limits_cpu)
